==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Burim",
    "Room" : "Dhomë",
    "Unknown" : "E panjohur",
    "Required" : "E domosdoshme",
    "Optional" : "Në dëshirë",
    "Does not attend" : "Nuk merr pjesë",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Gjendeni një zonë kohore të panjohur ({tz}), po përdoret parazgjedhja UTC",
    "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
    "New event" : "Veprimtari e re",
    "Attendees" : "Pjesëmarrës",
    "Reminders" : "Kujtues",
    "Repeating" : "Përsëritëse",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Confirmed" : "E ripohuar",
    "Tentative" : "Në tentativë",
    "Cancelled" : "Anuluar",
    "Please add a title!" : "Ju lutemi, shtoni një titull!",
    "Please select a calendar!" : "Ju lutemi, përzgjidhni një kalendar",
    "Global" : "Globale",
    "None" : "Asnjë",
    "Every day" : "Çdo ditë",
    "Every week" : "Çdo javë",
    "Every month" : "Çdo muaj",
    "Every year" : "Çdo vit",
    "never" : "kurrë",
    "after" : "pas",
    "At time of event" : "Në kohën e veprimtarisë",
    "5 minutes before" : "5 minuta para",
    "10 minutes before" : "10 minuta para",
    "15 minutes before" : "15 minuta para",
    "30 minutes before" : "30 minuta para",
    "1 hour before" : "1 orë para",
    "2 hours before" : "2 orë para",
    "Custom" : "E përshtatur",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Shfaqe si flluskë",
    "sec" : "sek",
    "min" : "min",
    "hours" : "orë",
    "days" : "ditë",
    "week" : "javë",
    "before" : "përpara",
    "start" : "fillim",
    "end" : "mbarim",
    "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Successfully imported" : "U importua me sukses",
    "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
    "Partially imported, {n} failures" : "Importuar pjesërisht, {n} dështime",
    "Audio alarm" : "Alarm audio",
    "Pop-up" : "Flluskë",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
    "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
    "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
    "{type} {time} after the event ends" : "{type} {time} pas mbarimit të veprimtarisë",
    "{type} at the event's start" : "{type} në fillim të veprimtarisë",
    "{type} at the event's end" : "{type} në fund të veprimtarisë",
    "{type} at {time}" : "{type} në {time}",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Title of the Event" : "Titulli i Veprimtarisë",
    "starts" : "fillon",
    "ends" : "mbaron",
    "All day Event" : "Veprimtari Gjithëditore",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "More ..." : "Më tepër …",
    "Create" : "Krijoje",
    "Update" : "Përditësoje",
    "Close" : "Mbylle",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Event status" : "Gjendje veprimtarie",
    "Visibility when sharing" : "Dukshmëri gjatë ndarjes me të tjerë",
    "Export" : "Eksportoji",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ju lutemi, lidhuni me përgjegjësin tuaj dhe kërkojini të çaktivizojë mundësinë \"asset-pipeline.enabled\" te formësimet.",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "Today" : "Sot",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
    "Share Calendar" : "Ndani Kalendar",
    "Shared" : "E ndarë",
    "More" : "Më tepër",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "Download" : "Shkarkoje",
    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
    "can edit" : "mund të përpunojnë",
    "group" : "grup",
    "New Calendar" : "Kalendar i ri",
    "Subscriptions" : "Pajtime",
    "New Subscription" : "Pajtim i Ri",
    "Url" : "URL",
    "Edit event" : "Përpunoni veprimtarinë",
    "Delete Event" : "Fshije Veprimtarinë",
    "Save Event" : "Ruaje Veprimtarinë",
    "Time" : "Kohë",
    "Type" : "Lloj",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Përsërite",
    "times every" : "herë çdo",
    "Add" : "Shtoje",
    "E-Mail address of attendee" : "Adresa email e pjesëmarrësit",
    "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
    "from" : "nga",
    "to" : "për",
    "This event's repeating rule is not supported yet." : "Ky rregull përsëritjesh veprimtarie nuk mbulohet ende.",
    "Support for advanced rules will be added with subsequent updates." : "Mbulimi i rregullave të thelluara do të shtohet në përditësimet e ardhshme.",
    "Reset repeating rule" : "Ricaktoni rregull përsëritje",
    "Repeat every ..." : "Përsërite çdo …",
    "end repeat ..." : "përfundoje përsëritjen më …",
    "times" : "herë",
    "Import Calendars" : "Importoni Kalendarë",
    "Import canceled" : "Importimi u anulua",
    "Analyzing calendar" : "Analizim kalendari",
    "The file contains objects incompatible with the selected calendar" : "Kartela përmban objekte të papërputhshme me kalendarin e përzgjedhur",
    "New calendar" : "Kalendar i ri",
    "Import scheduled" : "Importimi u planifikua",
    "Settings" : "Rregullime",
    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
    "Import calendar" : "Importo kalendar",
    "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
    "Primary CalDAV address" : "Adresë CalDAV parësore",
    "iOS/OS X CalDAV address" : "Adresë iOS/OS X CalDAV"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.4.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendar",
    "Individual" : "Individual",
    "Group" : "Grup",
    "Resource" : "Burim",
    "Room" : "Dhomë",
    "Unknown" : "E panjohur",
    "Required" : "E domosdoshme",
    "Optional" : "Në dëshirë",
    "Does not attend" : "Nuk merr pjesë",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Gjendeni një zonë kohore të panjohur ({tz}), po përdoret parazgjedhja UTC",
    "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
    "New event" : "Veprimtari e re",
    "Error saving WebCal-calendar" : "Gabim në ruajtje kalendari WebCal-calendar",
    "group" : "grup",
    "Attendees" : "Pjesëmarrës",
    "Reminders" : "Kujtues",
    "Repeating" : "Përsëritëse",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Confirmed" : "E ripohuar",
    "Tentative" : "Në tentativë",
    "Cancelled" : "Anuluar",
    "Please add a title!" : "Ju lutemi, shtoni një titull!",
    "Please select a calendar!" : "Ju lutemi, përzgjidhni një kalendar",
    "Global" : "Globale",
    "None" : "Asnjë",
    "Every day" : "Çdo ditë",
    "Every week" : "Çdo javë",
    "Every month" : "Çdo muaj",
    "Every year" : "Çdo vit",
    "never" : "kurrë",
    "after" : "pas",
    "At time of event" : "Në kohën e veprimtarisë",
    "5 minutes before" : "5 minuta para",
    "10 minutes before" : "10 minuta para",
    "15 minutes before" : "15 minuta para",
    "30 minutes before" : "30 minuta para",
    "1 hour before" : "1 orë para",
    "2 hours before" : "2 orë para",
    "Custom" : "E përshtatur",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Shfaqe si flluskë",
    "sec" : "sek",
    "min" : "min",
    "hours" : "orë",
    "days" : "ditë",
    "week" : "javë",
    "before" : "përpara",
    "start" : "fillim",
    "end" : "mbarim",
    "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Successfully imported" : "U importua me sukses",
    "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
    "Partially imported, {n} failures" : "Importuar pjesërisht, {n} dështime",
    "Audio alarm" : "Alarm audio",
    "Pop-up" : "Flluskë",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
    "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
    "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
    "{type} {time} after the event ends" : "{type} {time} pas mbarimit të veprimtarisë",
    "{type} at the event's start" : "{type} në fillim të veprimtarisë",
    "{type} at the event's end" : "{type} në fund të veprimtarisë",
    "{type} at {time}" : "{type} në {time}",
    "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
    "Please enter a valid WebCal-URL" : "Ju lutemi, jepni një url të vlefshme WebCal-URL",
    "Title of the Event" : "Titulli i Veprimtarisë",
    "starts" : "fillon",
    "ends" : "mbaron",
    "All day Event" : "Veprimtari Gjithëditore",
    "Delete" : "Fshije",
    "Cancel" : "Anuloje",
    "More ..." : "Më tepër …",
    "Create" : "Krijoje",
    "Update" : "Përditësoje",
    "Close" : "Mbylle",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Event status" : "Gjendje veprimtarie",
    "Visibility when sharing" : "Dukshmëri gjatë ndarjes me të tjerë",
    "Export" : "Eksportoji",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ju lutemi, lidhuni me përgjegjësin tuaj dhe kërkojini të çaktivizojë mundësinë \"asset-pipeline.enabled\" te formësimet.",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "Today" : "Sot",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
    "Share Calendar" : "Ndani Kalendar",
    "Shared" : "E ndarë",
    "More" : "Më tepër",
    "Edit" : "Përpunoni",
    "Link" : "Lidhje",
    "WebCal URL" : "URL WebCal",
    "Download" : "Shkarkoje",
    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
    "can edit" : "mund të përpunojnë",
    "New Calendar" : "Kalendar i ri",
    "Name" : "Emër",
    "New Subscription" : "Pajtim i Ri",
    "WebCal-URL" : "WebCal-URL",
    "Edit event" : "Përpunoni veprimtarinë",
    "Delete Event" : "Fshije Veprimtarinë",
    "Save Event" : "Ruaje Veprimtarinë",
    "Time" : "Kohë",
    "Type" : "Lloj",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Përsërite",
    "times every" : "herë çdo",
    "Add" : "Shtoje",
    "E-Mail address of attendee" : "Adresa email e pjesëmarrësit",
    "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
    "from" : "nga",
    "to" : "për",
    "This event's repeating rule is not supported yet." : "Ky rregull përsëritjesh veprimtarie nuk mbulohet ende.",
    "Support for advanced rules will be added with subsequent updates." : "Mbulimi i rregullave të thelluara do të shtohet në përditësimet e ardhshme.",
    "Reset repeating rule" : "Ricaktoni rregull përsëritje",
    "Repeat every ..." : "Përsërite çdo …",
    "end repeat ..." : "përfundoje përsëritjen më …",
    "times" : "herë",
    "Import Calendars" : "Importoni Kalendarë",
    "Import canceled" : "Importimi u anulua",
    "Analyzing calendar" : "Analizim kalendari",
    "The file contains objects incompatible with the selected calendar" : "Kartela përmban objekte të papërputhshme me kalendarin e përzgjedhur",
    "New calendar" : "Kalendar i ri",
    "Import scheduled" : "Importimi u planifikua",
    "Settings" : "Rregullime",
    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
    "Show week numbers" : "Shfaq numra javësh",
    "Import calendar" : "Importo kalendar",
    "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
    "Primary CalDAV address" : "Adresë CalDAV parësore",
    "iOS/OS X CalDAV address" : "Adresë iOS/OS X CalDAV"
},
"nplurals=2; plural=(n != 1);");
